@@ -34,11 +34,18 @@
 #include <unistd.h>
 
 /* Interfaces & Addresses */
+#include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <net/if.h>
-#include <netpacket/packet.h>
-#include <netinet/ether.h>
+
+#ifdef __linux__
+# include <netpacket/packet.h>
+# include <netinet/ether.h>
+#else
+# include <net/ethernet.h>
+#endif
+
 #include <ifaddrs.h>
 #include <arpa/inet.h>
 
@@ -72,7 +79,7 @@ struct _GNetworkInterfaceInfo
   gchar *hw_address;
   gchar *hw_broadcast_or_destination;
 
-  GNetworkInterfaceFlags flags:15;
+  GNetworkInterfaceFlags flags:16;
   GNetworkProtocols protocols:3;
 };
 
@@ -126,6 +133,7 @@ append_iface_info_from_interface (GNetworkInterfaceInfo * info, struct ifaddrs *
       _gnetwork_ip_address_set_from_sockaddr (&(info->ip6_netmask), data->ifa_netmask);
       _gnetwork_ip_address_set_from_sockaddr (&(info->ip6_destination), data->ifa_dstaddr);
       break;
+#ifdef AF_PACKET
     case AF_PACKET:
       info->protocols |= GNETWORK_PROTOCOL_PACKET;
 
@@ -134,6 +142,7 @@ append_iface_info_from_interface (GNetworkInterfaceInfo * info, struct ifaddrs *
       info->hw_address = _gnetwork_sockaddr_get_address (data->ifa_addr);
       info->hw_broadcast_or_destination = _gnetwork_sockaddr_get_address (data->ifa_dstaddr);
       break;
+#endif
     }
 }
 
@@ -150,8 +159,68 @@ create_info_from_interface (struct ifaddrs *data)
   info->ip4_multicasts = NULL;
   info->ip6_multicasts = NULL;
 
+  info->flags = GNETWORK_INTERFACE_NONE;
+
   /* Flags */
-  info->flags = data->ifa_flags;
+  if (data->ifa_flags & IFF_UP)
+    info->flags |= GNETWORK_INTERFACE_IS_UP;
+
+  if (data->ifa_flags & IFF_RUNNING)
+    info->flags |= GNETWORK_INTERFACE_IS_RUNNING;
+
+  if (data->ifa_flags & IFF_DEBUG)
+    info->flags |= GNETWORK_INTERFACE_IS_DEBUGGING;
+
+  if (data->ifa_flags & IFF_LOOPBACK)
+    info->flags |= GNETWORK_INTERFACE_IS_LOOPBACK;
+
+  if (data->ifa_flags & IFF_POINTOPOINT)
+    info->flags |= GNETWORK_INTERFACE_IS_POINT_TO_POINT;
+
+#ifdef IFF_MASTER
+  if (data->ifa_flags & IFF_MASTER)
+    info->flags |= GNETWORK_INTERFACE_IS_LOAD_MASTER;
+#endif /* IFF_MASTER */
+
+#ifdef IFF_SLAVE
+  if (data->ifa_flags & IFF_SLAVE)
+    info->flags |= GNETWORK_INTERFACE_IS_LOAD_SLAVE;
+#endif /* IFF_SLAVE */
+
+  if (data->ifa_flags & IFF_BROADCAST)
+    info->flags |= GNETWORK_INTERFACE_CAN_BROADCAST;
+
+  if (data->ifa_flags & IFF_MULTICAST)
+    info->flags |= GNETWORK_INTERFACE_CAN_MULTICAST;
+
+#ifdef IFF_NOTRAILERS
+  if (data->ifa_flags & IFF_NOTRAILERS)
+    info->flags |= GNETWORK_INTERFACE_NO_TRAILERS;
+#endif /* IFF_NOTRAILERS */
+
+  if (data->ifa_flags & IFF_NOARP)
+    info->flags |= GNETWORK_INTERFACE_NO_ARP;
+
+#ifdef IFF_PORTSEL
+  if (data->ifa_flags & IFF_PORTSEL)
+    info->flags |= GNETWORK_INTERFACE_CAN_SET_MEDIA;
+#endif /* IFF_PORTSEL */
+
+#ifdef IFF_ALTPHYS
+  if (data->ifa_flags & IFF_ALTPHYS)
+    info->flags |= GNETWORK_INTERFACE_ALTERNATE_LINK;
+#endif /* IFF_ALTPHYS */
+
+#ifdef IFF_AUTOMEDIA
+  if (data->ifa_flags & IFF_AUTOMEDIA)
+    info->flags |= GNETWORK_INTERFACE_AUTOSELECTED_MEDIA;
+#endif /* IFF_AUTOMEDIA */
+
+  if (data->ifa_flags & IFF_PROMISC)
+    info->flags |= GNETWORK_INTERFACE_RECV_ALL_PACKETS;
+
+  if (data->ifa_flags & IFF_ALLMULTI)
+    info->flags |= GNETWORK_INTERFACE_RECV_ALL_MULTICAST;
 
   return info;
 }
